<nav class="navbar navbar-expand-lg bg-light w-100 sticky-top header">
    <div class="container-fluid">
        <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarSupportedContent" aria-controls="navbarSupportedContent" aria-expanded="false" aria-label="Toggle navigation">
            <span class="navbar-toggler-icon"></span>
        </button>
        <h1 class="navbar-brand ms-0"><a href="{{ url('') }}" class="text-body fs-2">Barrin's Codex</a></h1>
        <div class="collapse navbar-collapse" id="navbarSupportedContent">
            <ul class="navbar-nav ms-auto me-auto mb-2 mb-lg-0">
                <li class="nav-item dropdown">
                    {% include "menu/pilotes.html" %}
                </li>
                <li class="nav-item dropdown">
                    {% include "menu/decks.html" %}
                </li>
                <li class="nav-item dropdown">
                    {% include "menu/matchs.html" %}
                </li>
            </ul>
        </div>
    </div>
</nav>
