{% extends "matchs/_layout_decks.html" %}

### PRESENTATION ###
{% block analyse %}
    La version présentée de Kari Zev a la capacité d'alterner entre les rôle
    d'agresseuse et de défenseuse. Cependant, le développement agressif
    linéaire de Marath permet de maintenir un flot de créatures attaquantes
    assez soutenu qui mettra en difficulté continuellement Kari Zev. Au final,
    le matchup semble être en faveur de Marath car la forte densité de
    créatures suffit à prendre l'avantage.
{% endblock %}


### JOUEURS ###
{% set joueur1 = "Spigushe" %}
{% set joueur2 = "Imperia86" %}

### VIDEO ###
{% set youtube = "https://www.youtube.com/embed/A-WfN-3JDtY" %}
{% set date = "8 février 2022" %}

### LEGENDE ###
{% block legende %}
<div class="d-flex flex-wrap justify-content-around py-2 mt-2">
    <div class="col-3 align-self-center">
        {{ pilote.spigushe() }}
    </div>
    <div class="col-3 px-1 align-self-center">
        {{ deck.card("/decks/marath-will-of-the-wild") }}
    </div>
    <div class="col-3 px-1 align-self-center">
        {{ deck.card("/decks/kari-zev-skyship-raider") }}
    </div>
    <div class="col-3 align-self-center">
        {{ pilote.imperia86() }}
    </div>
</div>
{% endblock %}
