<a class="nav-link dropdown-toggle" href="#" id="navbarDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">🧍 Pilotes</a>
<ul class="dropdown-menu" aria-labelledby="navbarDropdown">
    <li>{{ link("/pilotes", name="Liste des pilotes", _class="dropdown-item") }}</li>
    <li><hr class="dropdown-divider"></li>
    <li>{{ link("/pilotes/domino", _class="dropdown-item") }}</li>
    <li>{{ link("/pilotes/louis-imperia86", _class="dropdown-item") }}</li>
    <li>{{ link("/pilotes/martin-spigushe", _class="dropdown-item") }}</li>
    <li>
        <a href="#" class="dropdown-item" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">⤵️ Invité·e·s</a>
        <ul class="submenu dropdown-menu">
            <li>{{ link("/pilotes/anael-aliquanto", _class="dropdown-item") }}</li>
            <li>{{ link("/pilotes/bastien-threem", _class="dropdown-item") }}</li>
            <li>{{ link("/pilotes/damien-eventwin", _class="dropdown-item") }}</li>
            <li>{{ link("/pilotes/felix-midas", _class="dropdown-item") }}</li>
            <li>{{ link("/pilotes/florian-trotte", _class="dropdown-item") }}</li>
            <li>{{ link("/pilotes/gregoire-koraysh", _class="dropdown-item") }}</li>
            <li>{{ link("/pilotes/apparitions", _class="dropdown-item") }}</li>
        </ul>
    </li>
</ul>
