<a class="nav-link dropdown-toggle" href="#" id="navbarDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">📝 Decks</a><ul class="dropdown-menu" aria-labelledby="navbarDropdown">
    <li>{{ link("/decks", name="Liste des decks",  _class="dropdown-item") }}</li>
    <li><hr class="dropdown-divider"></li>
    <li>
        <a href="#" class="dropdown-item" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">🗡️ Agro</a>
        <ul class="submenu dropdown-menu">
            <li>{{ link("/decks/elmarsophina", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/hogaak-arisen-necropolis", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/isamaru-hound-of-konda", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/juri-master-of-the-revue", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/kari-zev-skyship-raider", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/karlov-of-the-ghost-council", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/killian-ink-duelist", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/livioprava", _class="dropdown-item") }}</li>
            <!-- # Deck banni
                <li>{{ link("/decks/minscboo-timeless-heroes", _class="dropdown-item") }}</li>
            -->
            <li>{{ link("/decks/wilson-refined-grizzly", _class="dropdown-item") }}</li>
        </ul>
    </li>
    <li>
        <a href="#" class="dropdown-item" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">⌚ Tempo</a>
        <ul class="submenu dropdown-menu">
            <li>{{ link("/decks/adeliz-the-cinder-wind", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/raffine-scheming-seer", _class="dropdown-item") }}</li>
        </ul>
    </li>
    <li>
        <a href="#" class="dropdown-item" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">⛓️ Contrôle</a>
        <ul class="submenu dropdown-menu">
            <li>{{ link("/decks/aminatou-the-fateshifter", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/azusa-lost-but-seeking", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/bjornawernog", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/dragonlord-ojutai", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/elminster", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/esika-god-of-the-tree", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/hinata-dawncrowned", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/ishaitevesh", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/jori-en-ruin-diver", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/klothys-god-of-destiny", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/miaratevesh", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/sai-master-thopterist", _class="dropdown-item") }}</li>
            <!-- # Deck banni
                <li>{{ link("/decks/shorikai-genesis-engine", _class="dropdown-item") }}</li>
            -->
            <li>{{ link("/decks/sygg-river-cutthroat", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/the-reality-chip", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/tivit-seller-of-secrets", _class="dropdown-item") }}</li>
        </ul>
    </li>
    <li>
        <a href="#" class="dropdown-item" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">✨ Combo</a>
        <ul class="submenu dropdown-menu">
            <li>{{ link("/decks/kinnan-bonder-prodigy", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/lightpaws-emperors-voice", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/maelstrom-wanderer", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/minsc-beloved-ranger", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/prossh-skyraider-of-kher", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/sythis-harvests-hand", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/the-beamtown-bullies", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/the-gitrog-monster", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/tiamat", _class="dropdown-item") }}</li>
        </ul>
    </li>
    <li>
        <a href="#" class="dropdown-item" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">🦏 Midrange</a>
        <ul class="submenu dropdown-menu">
            <li>{{ link("/decks/dennick-pious-apprentice", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/doran-the-siege-tower", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/elmarhargilde", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/grist-the-hunger-tide", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/liviomalcolm", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/marath-will-of-the-wild", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/nivmizzet-reborn", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/queen-marchesa", _class="dropdown-item") }}</li>
            <li>{{ link("/decks/saskia-the-unyielding", _class="dropdown-item") }}</li>
        </ul>
    </li>
</ul>
