{% extends "matchs/_layout_decks.html" %}

### PRESENTATION ###
{% block analyse %}
    La version créatures de Niv-Mizzet permet au deck d'utiliser ses ressources
    plus agressivement. Cependant, la posture réactive de Esika lui permet
    d'encaisser une grande partie de la pression. De plus, le deck est en
    mesure d'empêcher la résolution de Niv-Mizzet lui refusant tout moyen de
    récupérer des ressources qui seraient nécessaires pour remporter la partie.
    Au final, le matchup est assez équilibré et pousse les pilotes à multiplier
    les interactions.
{% endblock %}


### JOUEURS ###
{% set joueur1 = "Midas" %}
{% set joueur2 = "Imperia86" %}

### VIDEO ###
{% set youtube = "https://www.youtube.com/embed/20aRBNFAwrU" %}
{% set date = "25 janvier 2022" %}

### LEGENDE ###
{% block legende %}
<div class="d-flex flex-wrap justify-content-around py-2 mt-2">
    <div class="col-3 align-self-center">
        {{ pilote.midas() }}
    </div>
    <div class="col-3 px-1 align-self-center">
        {{ deck.card("/decks/esika-god-of-the-tree") }}
    </div>
    <div class="col-3 px-1 align-self-center">
        {{ deck.card("/decks/nivmizzet-reborn") }}
    </div>
    <div class="col-3 align-self-center">
        {{ pilote.imperia86() }}
    </div>
</div>
{% endblock %}
