<a class="nav-link dropdown-toggle" href="#" id="navbarDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">⏯️ Matchs</a><ul class="dropdown-menu" aria-labelledby="navbarDropdown">
    <li>{{ link("/matchs", name="Liste des matchs",  _class="dropdown-item") }}</li>
    <li><hr class="dropdown-divider"></li>
    <li>
        <a href="#" class="dropdown-item" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">21 à 30</a>
        <ul class="submenu dropdown-menu">
            <li>{{ link("/matchs/21-aminatou-vs-beamtown", _class="dropdown-item") }}</li>
            <li>{{ link("/matchs/22-raffine-vs-tivit", _class="dropdown-item") }}</li>
            <li>{{ link("/matchs/23-karlov-vs-reality-chip", _class="dropdown-item") }}</li>
            <li>{{ link("/matchs/24-grist-vs-minscboo", _class="dropdown-item") }}</li>
            <li>{{ link("/matchs/25-elminster-vs-wilson", _class="dropdown-item") }}</li>
            <li>{{ link("/matchs/26-hogaak-vs-minscboo", _class="dropdown-item") }}</li>
            <li>{{ link("/matchs/27-jori-en-vs-maelstrom-wanderer", _class="dropdown-item") }}</li>
            <li>{{ link("/matchs/28-azusa-vs-elmarhargilde", _class="dropdown-item") }}</li>
        </ul>
    </li>
    <li>
        <a href="#" class="dropdown-item" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">11 à 20</a>
        <ul class="submenu dropdown-menu">
            <li>{{ link("/matchs/11-doran-vs-marchesa", _class="dropdown-item") }}</li>
            <li>{{ link("/matchs/12-light-paws-vs-ishaitevesh", _class="dropdown-item") }}</li>
            <li>{{ link("/matchs/13-bjornawernog-vs-grist", _class="dropdown-item") }}</li>
            <li>{{ link("/matchs/14-minsc-vs-shorikai", _class="dropdown-item") }}</li>
            <li>{{ link("/matchs/15-dennick-vs-hinata", _class="dropdown-item") }}</li>
            <li>{{ link("/matchs/16-aminatou-vs-tiamat", _class="dropdown-item") }}</li>
            <li>{{ link("/matchs/17-grist-vs-sythis", _class="dropdown-item") }}</li>
            <li>{{ link("/matchs/18-kari-zev-vs-killian-budget", _class="dropdown-item") }}</li>
            <li>{{ link("/matchs/19-elmarsophina-vs-shorikai", _class="dropdown-item") }}</li>
            <li>{{ link("/matchs/20-juri-vs-sai", _class="dropdown-item") }}</li>
        </ul>
    </li>
    <li>
        <a href="#" class="dropdown-item" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">1 à 10</a>
        <ul class="submenu dropdown-menu">
            <li>{{ link("/matchs/1-adeliz-vs-kinnan", _class="dropdown-item") }}</li>
            <li>{{ link("/matchs/2-kari-zev-vs-saskia", _class="dropdown-item") }}</li>
            <li>{{ link("/matchs/3-isamaru-vs-gitrog", _class="dropdown-item") }}</li>
            <li>{{ link("/matchs/4-liviomalcolm-vs-niv-5c", _class="dropdown-item") }}</li>
            <li>{{ link("/matchs/5-jori-en-vs-sygg", _class="dropdown-item") }}</li>
            <li>{{ link("/matchs/6-aminatou-vs-klothys", _class="dropdown-item") }}</li>
            <li>{{ link("/matchs/7-livioprava-vs-ojutai", _class="dropdown-item") }}</li>
            <li>{{ link("/matchs/8-esika-vs-niv-5c", _class="dropdown-item") }}</li>
            <li>{{ link("/matchs/9-miaratevesh-vs-prossh", _class="dropdown-item") }}</li>
            <li>{{ link("/matchs/10-kari-zev-vs-marath", _class="dropdown-item") }}</li>
        </ul>
    </li>
</ul>
