{% extends "matchs/_layout_decks.html" %}

### PRESENTATION ###
{% block analyse %}
    La version un peu plus lente de Kinnan proposée dans cette vidéo laisse à
    penser que la configuration mettra Adeliz davantage en difficulté par
    rapport à une version combo dite classique. Même si Adeliz a de quoi gérer
    les petites créatures du début de partie, le deck peut être rapidement mis
    en difficulté si des créatures plus imposantes arrivent tôt en jeu.
{% endblock %}


### JOUEURS ###
{% set joueur1 = "Spigushe" %}
{% set joueur2 = "Trotte" %}

### VIDEO ###
{% set youtube = "https://www.youtube.com/embed/0LTuy09DUEg" %}
{% set date = "25 novembre 2021" %}

### LEGENDE ###
{% block legende %}
<div class="d-flex flex-wrap justify-content-around py-2 mt-2">
    <div class="col-3 align-self-center">
        {{ pilote.spigushe() }}
    </div>
    <div class="col-3 px-1 align-self-center">
        {{ deck.card("/decks/kinnan-bonder-prodigy") }}
    </div>
    <div class="col-3 px-1 align-self-center">
        {{ deck.card("/decks/adeliz-the-cinder-wind") }}
    </div>
    <div class="col-3 align-self-center">
        {{ pilote.trotte() }}
    </div>
</div>
{% endblock %}
