{% extends "decks/_layout_decks.html" %}

### PRESENTATION ###
{% block first_paragraph %}
    Le deck emmené par Tivit est un Esper/Obscura contrôle assez typique de ce
    que peut produire l'identité de couleur en Duel Commander. L'intérêt
    particulier est donc la capacité de Tivit qui permet de s'adapter au rythme
    de la partie.
{% endblock %}
{% block second_paragraph %}
    En votant deux fois avant l'adversaire, il est important de choisir au
    moins un jeton qui est essentiel pour le ou les prochains tours. En effet,
    il faudra que Tivit inflige des blessures de combat à l'adversaire pour
    pouvoir recréer des jetons.
{% endblock %}
{% block third_paragraph %}
{% endblock %}


### LISTES ###
{% block lien %}
https://www.moxfield.com/decks/AXlOspsIDEOOchZAMG2izw
{% endblock %}


### MATCHS ###
{% block matchs %}
{{ match.card2("/matchs/22-raffine-vs-tivit", "Lutte au cœur de Capenna pour la domination de la mafia. Quel sphinx de Raffine ou de Tivit sera sacré meilleur·e yakuza ?") }}
{% endblock %}


### PILOTES ###
{% block pilotes %}
<div class="row py-3 d-flex flex-wrap justify-content-around">
    <div class="col-sm-4">
        {{ pilote.domino(played_on="17 mai 2022") }}
    </div>
</div>
{% endblock %}
