{% extends "matchs/_layout_decks.html" %}

### PRESENTATION ###
{% block analyse %}
{% endblock %}


### JOUEURS ###
{% set joueur1 = "threem" %}
{% set joueur2 = "Domino" %}

### VIDEO ###
{% set youtube = "https://www.youtube.com/embed/gi1c20kB4pw" %}
{% set date = "21 juin 2022" %}

### LEGENDE ###
{% block legende %}
<div class="d-flex flex-wrap justify-content-around py-2 mt-2">
    <div class="col-3 align-self-center">
        {{ pilote.threem() }}
    </div>
    <div class="col-3 px-1 align-self-center">
        {{ deck.card("/decks/hogaak-arisen-necropolis") }}
    </div>
    <div class="col-3 px-1 align-self-center">
        {{ deck.card("/decks/minscboo-timeless-heroes") }}
    </div>
    <div class="col-3 align-self-center">
        {{ pilote.domino() }}
    </div>
</div>
{% endblock %}
